@@ -25,29 +25,25 @@ class HomeAssistantCog(commands.Cog):
     @app_commands.choices(choices=get_functions(ha.Vacuum))
     @commands.has_role("Shiny")
     async def vacuum(self, context: discord.Interaction, choices: str):
-        # print(await self.get_functions())
         roomba = ha.Vacuum()
-        roomba_function = getattr(roomba, choices)
-        roomba_function()
+        getattr(roomba, choices)()
         await context.response.send_message(f"Vacuum is {choices}ing")
 
     @app_commands.command(name="alarm")
     @app_commands.choices(choices=get_functions(ha.Alarm))
     @commands.has_role("Shiny")
     async def arm(self, context: discord.Interaction, choices: str):
-        # print(await self.get_functions())
         alarm = ha.Alarm()
         getattr(alarm, choices)()
-        await context.response.send_message(f"Testing is {choices}ing")
+        await context.response.send_message(f"Alarm is {choices}ing")
 
     @app_commands.command(name="taylor_swiftly")
-    @app_commands.choices(choices=get_functions(ha.Lock))
+    @app_commands.choices(choices=get_functions(ha.TaylorSwiftly))
     @commands.has_role("Shiny")
     async def tesla(self, context: discord.Interaction, choices: str):
-        # print(await self.get_functions())
-        taylor = ha.Lock(entity_id="taylor_swiftly_doors", location="home")
+        taylor = ha.TaylorSwiftly()
         status = getattr(taylor, choices)()
-        await context.response.send_message(f"Testing is {status}")
+        await context.response.send_message(f"Taylor Swiftly is {status}")
 
 
 async def setup(client: commands.Cog):
