@@ -1,6 +1,7 @@
 """Home Assistant module for Shiny API."""
 import inspect
 import os
+from pprint import pprint
 from homeassistant_api import Client
 import shiny_api.modules.load_config as config
 
@@ -103,12 +104,37 @@ class Lock(HomeAssistant):
         self.client.get_domain(self.domain).unlock(entity_id=self.entity_id)
 
 
-# class Tesla
+class Sensor(HomeAssistant):
+    def __init__(self, *args, **kwargs):
+        self.domain = "sensor"
+        super().__init__(*args, **kwargs)
+
+
+class TaylorSwiftly:
+    """Class for Taylor Swiftly Lock"""
+
+    def __init__(self):
+        self.battery = Sensor("taylor_swiftly_battery", location="home")
+        self.lock = Lock("taylor_swiftly_doors", location="home")
+
+    def get_functions(self):
+        """Return functions"""
+        methods = {}
+        for class_name, class_method in vars(self).items():
+            for name in class_method.get_functions():
+                methods[f"{name} {class_name}"] = getattr(class_method, name)
+        # for method in inspect.getmembers(cls, predicate=inspect.):
+        #    print(method)
+        # methods = [method for method, _ in inspect.getmembers(cls, predicate=inspect.isfunction) if not method.startswith("__")]
+        return methods
 
 
 if __name__ == "__main__":
     # test = InputBoolean("testing")
     # print(test.status)
-    taylor = Lock("taylor_swiftly_doors", location="home")
+    taylor_lock = Lock("taylor_swiftly_doors", location="home")
+    taylor_batt = Sensor("taylor_swiftly_battery", location="home")
     # taylor.lock()
-    print(taylor.status)
+    taylor = TaylorSwiftly()
+    taylor.get_functions()["lock lock"]()
+    print(taylor.get_functions())
